@@ -1,4 +1,4 @@
-// Service to verify accounts hashes with other trusted validator nodes.
+// Service to verify accounts hashes with other known validator nodes.
 //
 // Each interval, publish the snapshat hash which is the full accounts state
 // hash on gossip. Monitor gossip for messages from validators in the `--known-validator`s
@@ -33,8 +33,8 @@ impl AccountsHashVerifier {
         pending_snapshot_package: Option<PendingSnapshotPackage>,
         exit: &Arc<AtomicBool>,
         cluster_info: &Arc<ClusterInfo>,
-        trusted_validators: Option<HashSet<Pubkey>>,
-        halt_on_trusted_validators_accounts_hash_mismatch: bool,
+        known_validators: Option<HashSet<Pubkey>>,
+        halt_on_known_validators_accounts_hash_mismatch: bool,
         fault_injection_rate_slots: u64,
         snapshot_interval_slots: u64,
     ) -> Self {
@@ -62,8 +62,8 @@ impl AccountsHashVerifier {
                             Self::process_accounts_package_pre(
                                 accounts_package,
                                 &cluster_info,
-                                &trusted_validators,
-                                halt_on_trusted_validators_accounts_hash_mismatch,
+                                &known_validators,
+                                halt_on_known_validators_accounts_hash_mismatch,
                                 &pending_snapshot_package,
                                 &mut hashes,
                                 &exit,
@@ -87,8 +87,8 @@ impl AccountsHashVerifier {
     fn process_accounts_package_pre(
         accounts_package: AccountsPackagePre,
         cluster_info: &ClusterInfo,
-        trusted_validators: &Option<HashSet<Pubkey>>,
-        halt_on_trusted_validator_accounts_hash_mismatch: bool,
+        known_validators: &Option<HashSet<Pubkey>>,
+        halt_on_known_validator_accounts_hash_mismatch: bool,
         pending_snapshot_package: &Option<PendingSnapshotPackage>,
         hashes: &mut Vec<(Slot, Hash)>,
         exit: &Arc<AtomicBool>,
@@ -103,8 +103,8 @@ impl AccountsHashVerifier {
         Self::process_accounts_package(
             accounts_package,
             cluster_info,
-            trusted_validators,
-            halt_on_trusted_validator_accounts_hash_mismatch,
+            known_validators,
+            halt_on_known_validator_accounts_hash_mismatch,
             pending_snapshot_package,
             hashes,
             exit,
@@ -116,8 +116,8 @@ impl AccountsHashVerifier {
     fn process_accounts_package(
         accounts_package: AccountsPackage,
         cluster_info: &ClusterInfo,
-        trusted_validators: &Option<HashSet<Pubkey>>,
-        halt_on_trusted_validator_accounts_hash_mismatch: bool,
+        known_validators: &Option<HashSet<Pubkey>>,
+        halt_on_known_validator_accounts_hash_mismatch: bool,
         pending_snapshot_package: &Option<PendingSnapshotPackage>,
         hashes: &mut Vec<(Slot, Hash)>,
         exit: &Arc<AtomicBool>,
@@ -143,12 +143,12 @@ impl AccountsHashVerifier {
             hashes.remove(0);
         }
 
-        if halt_on_trusted_validator_accounts_hash_mismatch {
+        if halt_on_known_validator_accounts_hash_mismatch {
             let mut slot_to_hash = HashMap::new();
             for (slot, hash) in hashes.iter() {
                 slot_to_hash.insert(*slot, *hash);
             }
-            if Self::should_halt(cluster_info, trusted_validators, &mut slot_to_hash) {
+            if Self::should_halt(cluster_info, known_validators, &mut slot_to_hash) {
                 exit.store(true, Ordering::Relaxed);
             }
         }
@@ -164,20 +164,20 @@ impl AccountsHashVerifier {
 
     fn should_halt(
         cluster_info: &ClusterInfo,
-        trusted_validators: &Option<HashSet<Pubkey>>,
+        known_validators: &Option<HashSet<Pubkey>>,
         slot_to_hash: &mut HashMap<Slot, Hash>,
     ) -> bool {
         let mut verified_count = 0;
         let mut highest_slot = 0;
-        if let Some(trusted_validators) = trusted_validators.as_ref() {
-            for trusted_validator in trusted_validators {
-                let is_conflicting = cluster_info.get_accounts_hash_for_node(trusted_validator, |accounts_hashes|
+        if let Some(known_validators) = known_validators.as_ref() {
+            for known_validator in known_validators {
+                let is_conflicting = cluster_info.get_accounts_hash_for_node(known_validator, |accounts_hashes|
                 {
                     accounts_hashes.iter().any(|(slot, hash)| {
                         if let Some(reference_hash) = slot_to_hash.get(slot) {
                             if *hash != *reference_hash {
-                                error!("Trusted validator {} produced conflicting hashes for slot: {} ({} != {})",
-                                    trusted_validator,
+                                error!("Known validator {} produced conflicting hashes for slot: {} ({} != {})",
+                                    known_validator,
                                     slot,
                                     hash,
                                     reference_hash,
@@ -241,11 +241,11 @@ mod tests {
         let cluster_info = new_test_cluster_info(contact_info);
         let cluster_info = Arc::new(cluster_info);
 
-        let mut trusted_validators = HashSet::new();
+        let mut known_validators = HashSet::new();
         let mut slot_to_hash = HashMap::new();
         assert!(!AccountsHashVerifier::should_halt(
             &cluster_info,
-            &Some(trusted_validators.clone()),
+            &Some(known_validators.clone()),
             &mut slot_to_hash,
         ));
 
@@ -258,10 +258,10 @@ mod tests {
             cluster_info.flush_push_queue();
         }
         slot_to_hash.insert(0, hash2);
-        trusted_validators.insert(validator1.pubkey());
+        known_validators.insert(validator1.pubkey());
         assert!(AccountsHashVerifier::should_halt(
             &cluster_info,
-            &Some(trusted_validators),
+            &Some(known_validators),
             &mut slot_to_hash,
         ));
     }
@@ -277,7 +277,7 @@ mod tests {
         let cluster_info = new_test_cluster_info(contact_info);
         let cluster_info = Arc::new(cluster_info);
 
-        let trusted_validators = HashSet::new();
+        let known_validators = HashSet::new();
         let exit = Arc::new(AtomicBool::new(false));
         let mut hashes = vec![];
         for i in 0..MAX_SNAPSHOT_HASHES + 1 {
@@ -297,7 +297,7 @@ mod tests {
             AccountsHashVerifier::process_accounts_package(
                 accounts_package,
                 &cluster_info,
-                &Some(trusted_validators.clone()),
+                &Some(known_validators.clone()),
                 false,
                 &None,
                 &mut hashes,
