@@ -3,23 +3,18 @@
 //! packing transactions into block; it also triggers persisting cost
 //! table to blockstore.
 
-use {
-    solana_ledger::blockstore::Blockstore,
-    solana_measure::measure::Measure,
-    solana_runtime::{
-        bank::{Bank, ExecuteTimings},
-        cost_model::CostModel,
-    },
-    solana_sdk::timing::timestamp,
-    std::{
-        sync::{
-            atomic::{AtomicBool, Ordering},
-            mpsc::Receiver,
-            Arc, RwLock,
-        },
-        thread::{self, Builder, JoinHandle},
-        time::Duration,
+use solana_ledger::blockstore::Blockstore;
+use solana_measure::measure::Measure;
+use solana_runtime::{bank::Bank, bank::ExecuteTimings, cost_model::CostModel};
+use solana_sdk::timing::timestamp;
+use std::{
+    sync::{
+        atomic::{AtomicBool, Ordering},
+        mpsc::Receiver,
+        Arc, RwLock,
     },
+    thread::{self, Builder, JoinHandle},
+    time::Duration,
 };
 
 #[derive(Default)]
@@ -208,7 +203,9 @@ impl CostUpdateService {
 
 #[cfg(test)]
 mod tests {
-    use {super::*, solana_runtime::message_processor::ProgramTiming, solana_sdk::pubkey::Pubkey};
+    use super::*;
+    use solana_runtime::message_processor::ProgramTiming;
+    use solana_sdk::pubkey::Pubkey;
 
     #[test]
     fn test_update_cost_model_with_empty_execute_timings() {
